@@ -11,6 +11,7 @@ import shutil
 import subprocess
 import time
 import urllib
+import pathlib
 
 import aiohttp
 
@@ -272,26 +273,23 @@ def bExecute(*pars):
     return p.returncode, outBytes, errBytes
 
 
-def bExecuteWinScp(winscpExe, winscpKeyFile, server, commandAry):
-    logFile = os.path.join(os.path.dirname(winscpExe), 'temp.log')
-    bMakeFolder(os.path.dirname(logFile))
+def bExecuteWinScp(winscpExe, keyFile, server, commandAry, showCmd=False):
+    logFile = bGetPath(pathlib.Path.home(), "bExecuteWinScp.log")
+    bRemove(logFile)
     ary = [
         'option batch abort',
         'option transfer binary',
-        'open sftp://%s -privatekey=%s' % (server, winscpKeyFile),
+        f'open sftp://{server} -privatekey={keyFile} -hostkey=*',
     ]
     ary += commandAry
     ary += [
         'close',
         'exit',
     ]
-    bRemove(logFile)
     # /console
-    cmd = '%s /log=%s /loglevel=0 /command %s' % (
-        winscpExe,
-        logFile,
-        ' '.join('"%s"' % x for x in ary),
-    )
+    cmd = f'{winscpExe} /log={logFile} /loglevel=0 /command ' + ' '.join('"%s"' % x for x in ary)
+    if showCmd:
+        bInfo(cmd)
     bExecute(cmd)
 
 
